<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl">
<context>
    <name>NotificationActionsComboWidget</name>
    <message>
        <location filename="../notificationwidgets.cpp" line="131"/>
        <source>Actions:</source>
        <translation>Accións:</translation>
    </message>
    <message>
        <location filename="../notificationwidgets.cpp" line="155"/>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
</context>
<context>
    <name>Notifyd</name>
    <message>
        <location filename="../notifyd.cpp" line="274"/>
        <source>Clear All</source>
        <translation>Limpar todo</translation>
    </message>
    <message>
        <location filename="../notifyd.cpp" line="285"/>
        <source>Do Not Disturb</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../notifyd.cpp" line="293"/>
        <source>Options</source>
        <translation>Opcións</translation>
    </message>
    <message numerus="yes">
        <location filename="../notifyd.cpp" line="300"/>
        <location filename="../notifyd.cpp" line="358"/>
        <location filename="../notifyd.cpp" line="379"/>
        <source>%n Unattended Notification(s)</source>
        <translation>
            <numerusform>%n notificación desatendida</numerusform>
            <numerusform>%n notificacións desatendidas</numerusform>
        </translation>
    </message>
</context>
</TS>
